#ifndef PYTHONIC_INCLUDE_STRING_OCTDIGITS_HPP
#define PYTHONIC_INCLUDE_STRING_OCTDIGITS_HPP

#include "pythonic/types/str.hpp"

PYTHONIC_NS_BEGIN

namespace string
{
  static types::str const octdigits("01234567");
}
PYTHONIC_NS_END

#endif
